@@ -143,7 +143,7 @@ void XwinExtensionInit(void)
 #if defined(DDXBEFORERESET)
 /*
  * Called right before KillAllClients when the server is going to reset,
- * allows us to shutdown our seperate threads cleanly.
+ * allows us to shutdown our separate threads cleanly.
  */
 
 void
@@ -169,7 +169,9 @@ main(int argc, char *argv[], char *envp[])
 {
     int iReturn;
 
+#ifdef __CYGWIN__
     xorg_crashreport_init(NULL);
+#endif
 
     /* Create & acquire the termination mutex */
     iReturn = pthread_mutex_init(&g_pmTerminating, NULL);
@@ -253,16 +255,6 @@ ddxGiveUp(enum ExitCode error)
     winDebug("ddxGiveUp - End\n");
 }
 
-/* See Porting Layer Definition - p. 57 */
-void
-AbortDDX(enum ExitCode error)
-{
-#if CYGDEBUG
-    winDebug("AbortDDX\n");
-#endif
-    ddxGiveUp(error);
-}
-
 #ifdef __CYGWIN__
 extern Bool nolock;
 
@@ -620,7 +612,7 @@ winFixupPaths(void)
             winMsg(X_ERROR, "Can not determine HOME directory\n");
         }
     }
-    if (!g_fLogFile) {
+    if (!g_pszLogFile) {
         static char buffer[MAX_PATH];
         DWORD size = GetTempPath(sizeof(buffer), buffer);
 
@@ -663,8 +655,10 @@ OsVendorInit(void)
         else
             g_pszLogFile = LogInit(g_pszLogFileFormat, ".old");
 
+#ifdef __CYGWIN__
         /* Tell crashreporter logfile name */
         xorg_crashreport_init(g_pszLogFile);
+#endif
     }
 
     LogSetParameter(XLOG_FLUSH, 1);
@@ -944,6 +938,8 @@ InitOutput(ScreenInfo * pScreenInfo, int argc, char *argv[])
     winConfigFiles();
 #endif
 
+    winUpdateDpi();
+
     /* Load preferences from XWinrc file */
     LoadPreferences();
 
