@@ -57,7 +57,6 @@
 #define WIN_DEFAULT_BLACKPIXEL			0
 #define WIN_DEFAULT_LINEBIAS			0
 #define WIN_DEFAULT_E3B_TIME			50      /* milliseconds */
-#define WIN_DEFAULT_DPI				96
 #define WIN_DEFAULT_REFRESH			0
 #define WIN_DEFAULT_WIN_KILL			TRUE
 #define WIN_DEFAULT_UNIX_KILL			FALSE
@@ -300,6 +299,7 @@ typedef struct {
     HBITMAP hBitmap;
     void *pbBits;
     BITMAPINFOHEADER *pbmih;
+    BOOL owned;
 } winPrivPixmapRec, *winPrivPixmapPtr;
 
 /*
@@ -470,7 +470,7 @@ typedef struct _winPrivScreenRec {
     void *pWMInfo;
     Bool fRootWindowShown;
 
-    /* Privates used for any module running in a seperate thread */
+    /* Privates used for any module running in a separate thread */
     pthread_mutex_t pmServerStarted;
     Bool fServerStarted;
 
@@ -761,6 +761,9 @@ void
  * winkeybd.c
  */
 
+int
+ winTranslateKey(WPARAM wParam, LPARAM lParam);
+
 int
  winKeybdProc(DeviceIntPtr pDeviceInt, int iState);
 
@@ -770,6 +773,20 @@ void
 void
  winRestoreModeKeyStates(void);
 
+Bool
+ winIsFakeCtrl_L(UINT message, WPARAM wParam, LPARAM lParam);
+
+void
+ winKeybdReleaseKeys(void);
+
+void
+ winSendKeyEvent(DWORD dwKey, Bool fDown);
+
+BOOL winCheckKeyPressed(WPARAM wParam, LPARAM lParam);
+
+void
+ winFixShiftKeys(int iScanCode);
+
 /*
  * winkeyhook.c
  */
@@ -798,7 +815,14 @@ int
  winMouseProc(DeviceIntPtr pDeviceInt, int iState);
 
 int
- winMouseButtonsHandle(ScreenPtr pScreen,
+ winMouseWheel(int *iTotalDeltaZ, int iDeltaZ, int iButtonUp, int iButtonDown);
+
+void
+ winMouseButtonsSendEvent(int iEventType, int iButton);
+
+int
+
+winMouseButtonsHandle(ScreenPtr pScreen,
                       int iEventType, int iButton, WPARAM wParam);
 
 void
@@ -1007,6 +1031,8 @@ winDoRandRScreenSetSize(ScreenPtr pScreen,
                         CARD16 width,
                         CARD16 height, CARD32 mmWidth, CARD32 mmHeight);
 
+void winUpdateDpi(void);
+
 /*
  * winmsgwindow.c
  */
