@@ -88,7 +88,6 @@ OR PERFORMANCE OF THIS SOFTWARE.
 #include <errno.h>
 
 #include "input.h"
-#include "site.h"
 #include "opaque.h"
 
 #ifdef WIN32
@@ -108,6 +107,14 @@ OR PERFORMANCE OF THIS SOFTWARE.
 void (*OsVendorVErrorFProc) (const char *, va_list args) = NULL;
 #endif
 
+/* Default logging parameters. */
+#ifndef DEFAULT_LOG_VERBOSITY
+#define DEFAULT_LOG_VERBOSITY		0
+#endif
+#ifndef DEFAULT_LOG_FILE_VERBOSITY
+#define DEFAULT_LOG_FILE_VERBOSITY	3
+#endif
+
 static FILE *logFile = NULL;
 static int logFileFd = -1;
 static Bool logFlush = FALSE;
@@ -866,7 +873,7 @@ AbortServer(void)
     CloseWellKnownConnections();
     OsCleanup(TRUE);
     AbortDevices();
-    AbortDDX(EXIT_ERR_ABORT);
+    ddxGiveUp(EXIT_ERR_ABORT);
     fflush(stderr);
     if (CoreDump)
         OsAbort();
